@@ -53,7 +53,6 @@
  * right of the line numbers.
  */
 
-/* Properties */
 enum
 {
 	PROP_0,
@@ -604,8 +603,8 @@ append_renderer (GtkSourceGutter *gutter,
 }
 
 GtkSourceGutter *
-gtk_source_gutter_new (GtkSourceView     *view,
-                       GtkTextWindowType  type)
+_gtk_source_gutter_new (GtkSourceView     *view,
+			GtkTextWindowType  type)
 {
 	return g_object_new (GTK_SOURCE_TYPE_GUTTER,
 	                     "view", view,
@@ -615,6 +614,36 @@ gtk_source_gutter_new (GtkSourceView     *view,
 
 /* Public API */
 
+/**
+ * gtk_source_gutter_get_view:
+ * @gutter: a #GtkSourceGutter.
+ *
+ * Returns: (transfer none): the associated #GtkSourceView.
+ * Since: 3.24
+ */
+GtkSourceView *
+gtk_source_gutter_get_view (GtkSourceGutter *gutter)
+{
+	g_return_val_if_fail (GTK_SOURCE_IS_GUTTER (gutter), NULL);
+
+	return gutter->priv->view;
+}
+
+/**
+ * gtk_source_gutter_get_window_type:
+ * @gutter: a #GtkSourceGutter.
+ *
+ * Returns: the #GtkTextWindowType of @gutter.
+ * Since: 3.24
+ */
+GtkTextWindowType
+gtk_source_gutter_get_window_type (GtkSourceGutter *gutter)
+{
+	g_return_val_if_fail (GTK_SOURCE_IS_GUTTER (gutter), GTK_TEXT_WINDOW_PRIVATE);
+
+	return gutter->priv->window_type;
+}
+
 /**
  * gtk_source_gutter_get_window:
  * @gutter: a #GtkSourceGutter.
@@ -1222,9 +1251,9 @@ end_draw (GtkSourceGutter *gutter)
 }
 
 void
-gtk_source_gutter_draw (GtkSourceGutter *gutter,
-                        GtkSourceView   *view,
-                        cairo_t         *cr)
+_gtk_source_gutter_draw (GtkSourceGutter *gutter,
+			 GtkSourceView   *view,
+			 cairo_t         *cr)
 {
 	GdkRectangle clip;
 	GtkTextView *text_view;
@@ -1447,17 +1476,17 @@ renderer_query_activatable (GtkSourceGutter *gutter,
 
 static gboolean
 redraw_for_window (GtkSourceGutter *gutter,
-                   GdkEventAny     *event,
-                   gboolean         act_on_window,
-                   gint             x,
-                   gint             y)
+		   GdkEvent        *event,
+		   gboolean         act_on_window,
+		   gint             x,
+		   gint             y)
 {
 	Renderer *at_x = NULL;
 	gint start = 0;
 	GList *item;
 	gboolean redraw;
 
-	if (event->window != get_window (gutter) && act_on_window)
+	if (event->any.window != get_window (gutter) && act_on_window)
 	{
 		return FALSE;
 	}
@@ -1486,7 +1515,7 @@ redraw_for_window (GtkSourceGutter *gutter,
 			}
 			else if (renderer_query_activatable (gutter,
 			                                     renderer,
-			                                     (GdkEvent *)event,
+			                                     event,
 			                                     x,
 			                                     y,
 			                                     NULL,
@@ -1518,7 +1547,7 @@ on_view_motion_notify_event (GtkSourceView    *view,
                              GtkSourceGutter  *gutter)
 {
 	return redraw_for_window (gutter,
-	                          (GdkEventAny *)event,
+	                          (GdkEvent *)event,
 	                          TRUE,
 	                          (gint)event->x,
 	                          (gint)event->y);
@@ -1530,7 +1559,7 @@ on_view_enter_notify_event (GtkSourceView     *view,
                             GtkSourceGutter   *gutter)
 {
 	return redraw_for_window (gutter,
-	                          (GdkEventAny *)event,
+	                          (GdkEvent *)event,
 	                          TRUE,
 	                          (gint)event->x,
 	                          (gint)event->y);
@@ -1542,7 +1571,7 @@ on_view_leave_notify_event (GtkSourceView     *view,
                             GtkSourceGutter   *gutter)
 {
 	return redraw_for_window (gutter,
-	                          (GdkEventAny *)event,
+	                          (GdkEvent *)event,
 	                          FALSE,
 	                          (gint)event->x,
 	                          (gint)event->y);
@@ -1717,8 +1746,12 @@ gtk_source_gutter_get_padding (GtkSourceGutter *gutter,
  *
  * Returns: (nullable) (transfer none): the renderer at (x, y) or %NULL.
  */
-/* FIXME: to insert a renderer in a gutter, only one position is needed. Here to
- * retrieve a renderer, two positions are needed? Document why.
+/* TODO: better document this function. The (x,y) position is different from
+ * the position passed to gtk_source_gutter_insert() and
+ * gtk_source_gutter_reorder(). The (x,y) coordinate can come from a click
+ * event, for example? Is the (x,y) a coordinate of the Gutter's GdkWindow?
+ * Where is the (0,0)? And so on.
+ * Also, this function doesn't seem to be used.
  */
 GtkSourceGutterRenderer *
 gtk_source_gutter_get_renderer_at_pos (GtkSourceGutter *gutter,
